PackedSeqVecBase

Struct PackedSeqVecBase 

pub struct PackedSeqVecBase<const B: usize>
where Bits<B>: SupportedBits,
{ /* private fields */ }
A variable-bit-width packed owned sequence of DNA bases.

Implementations

Source

impl<const B: usize> PackedSeqVecBase<B>
where Bits<B>: SupportedBits,

pub fn from_raw_parts(seq: Vec<u8>, len: usize) -> Self

Creates a SeqVec from a vector of packed bytes and a length in bp.

The vector should have at least 48 bytes of padding after len. Otherwise, the vector will be resized to be padded with zeros.

Source

impl PackedSeqVecBase<1>

pub fn with_len(n: usize) -> Self

pub fn random(len: usize, n_frac: f32) -> Self