u32x8

Struct u32x8 

pub struct u32x8 { /* private fields */ }
A SIMD vector containing 8 u32s.

Implementations

Source

impl u32x8

pub const ONE: u32x8

pub const ZERO: u32x8

pub const MAX: u32x8

pub const MIN: u32x8

pub const LANES: u16 = 8

The number of lanes in this SIMD vector.

pub const BITS: u16 = 256

The size of this SIMD vector in bits.

Source

impl u32x8

pub const fn new(array: [u32; 8]) -> u32x8

pub fn simd_eq<Rhs>(self, other: Rhs) -> <u32x8 as CmpEq<Rhs>>::Output
where u32x8: CmpEq<Rhs>,

Test if each element is equal to the corresponding element in other.

pub fn simd_ne<Rhs>(self, other: Rhs) -> <u32x8 as CmpNe<Rhs>>::Output
where u32x8: CmpNe<Rhs>,

Test if each element is not equal to the corresponding element in other.

pub fn simd_lt<Rhs>(self, other: Rhs) -> <u32x8 as CmpLt<Rhs>>::Output
where u32x8: CmpLt<Rhs>,

Test if each element is less than the corresponding element in other.

pub fn simd_gt<Rhs>(self, other: Rhs) -> <u32x8 as CmpGt<Rhs>>::Output
where u32x8: CmpGt<Rhs>,

Test if each element is greater than the corresponding element in other.

pub fn simd_le<Rhs>(self, other: Rhs) -> <u32x8 as CmpLe<Rhs>>::Output
where u32x8: CmpLe<Rhs>,

Test if each element is less than or equal to the corresponding element in other.

pub fn simd_ge<Rhs>(self, other: Rhs) -> <u32x8 as CmpGe<Rhs>>::Output
where u32x8: CmpGe<Rhs>,

Test if each element is greater than or equal to the corresponding element in other.

pub fn mul_keep_high(self, rhs: u32x8) -> u32x8

Multiplies 32x32 bit to 64 bit and then only keeps the high 32 bits of the result. Useful for implementing divide constant value (see t_usefulness example)

pub fn blend(self, t: u32x8, f: u32x8) -> u32x8

pub fn reduce_add(self) -> u32

pub fn reduce_max(self) -> u32

pub fn reduce_min(self) -> u32

pub fn max(self, rhs: u32x8) -> u32x8

pub fn min(self, rhs: u32x8) -> u32x8

pub fn clamp(self, min: u32x8, max: u32x8) -> u32x8

Restrict each element to a certain interval.

If min > max, the result is unspeficied. Consider manually checking for that case.

pub fn saturating_add(self, rhs: u32x8) -> u32x8

pub fn saturating_sub(self, rhs: u32x8) -> u32x8

pub fn saturating_mul(self, rhs: u32x8) -> u32x8

Lanewise saturating multiply.

pub fn saturating_div(self, rhs: u32x8) -> u32x8

Lanewise saturating divide.

Note that because division has no hardware support, this operation is very slow and should be avoided if possible.

pub fn to_bitmask(self) -> u32

pub fn any(self) -> bool

pub fn all(self) -> bool

pub fn none(self) -> bool

pub fn transpose(data: [u32x8; 8]) -> [u32x8; 8]

Transpose matrix of 8x8 u32 matrix. Currently only accelerated on AVX2.

pub fn to_array(self) -> [u32; 8]

pub fn as_array(&self) -> &[u32; 8]

pub fn as_mut_array(&mut self) -> &mut [u32; 8]

Source

impl u32x8

pub const fn splat(elem: u32) -> u32x8