pub struct PackedSeqVecBase<const B: usize>where
Bits<B>: SupportedBits,{ /* private fields */ }Expand description
A variable-bit-width packed owned sequence of DNA bases.
Implementations
Sourceimpl<const B: usize> PackedSeqVecBase<B>where
Bits<B>: SupportedBits,
impl<const B: usize> PackedSeqVecBase<B>where
Bits<B>: SupportedBits,
Sourcepub fn from_raw_parts(seq: Vec<u8>, len: usize) -> Self
pub fn from_raw_parts(seq: Vec<u8>, len: usize) -> Self
Creates a SeqVec from a vector of packed bytes and a length in bp.
The vector should have at least 48 bytes of padding after len.
Otherwise, the vector will be resized to be padded with zeros.