pub struct PackedNSeqVec {
pub seq: PackedSeqVec,
pub ambiguous: BitSeqVec,
}Fields
seq: PackedSeqVecambiguous: BitSeqVecImplementations
Sourceimpl PackedNSeqVec
Implement a subset of SeqVec for PackedNSeqVec.
impl PackedNSeqVec
Implement a subset of SeqVec for PackedNSeqVec.
pub fn clear(&mut self)
pub fn random(len: usize, n_frac: f32) -> Self
pub fn as_slice(&self) -> PackedNSeq<'_>
pub fn slice(&self, range: Range<usize>) -> PackedNSeq<'_>
pub fn push_ascii(&mut self, seq: &[u8]) -> Range<usize>
pub fn from_ascii(seq: &[u8]) -> Self
Sourcepub fn from_ascii_and_quality(
seq: &[u8],
quality: &[u8],
threshold: usize,
) -> Self
pub fn from_ascii_and_quality( seq: &[u8], quality: &[u8], threshold: usize, ) -> Self
Create a mask that is 1 for all non-ACGT bases and for all low-quality bases with quality <threshold.
Sourcepub fn push_from_ascii_and_quality(
&mut self,
seq: &[u8],
quality: &[u8],
min_qual: u8,
)
pub fn push_from_ascii_and_quality( &mut self, seq: &[u8], quality: &[u8], min_qual: u8, )
Create a mask that is 1 for all non-ACGT bases and for all low-quality bases with quality <threshold.
Sourcepub fn from_fastx(path: &Path) -> Self
pub fn from_fastx(path: &Path) -> Self
Read a fasta/fastq file at the given path into a PackedNSeq, separating records with N.
Sourcepub fn from_fastq_with_quality(path: &Path, min_qual: u8) -> Self
pub fn from_fastq_with_quality(path: &Path, min_qual: u8) -> Self
Read a fasta/fastq file at the given path into a PackedNSeq, separating records with N.
Low-quality bases are masked out.