pub struct u32x8 { /* private fields */ }Expand description
A SIMD vector containing 8 u32s.
Implementations
Sourceimpl u32x8
impl u32x8
pub const fn new(array: [u32; 8]) -> u32x8
Sourcepub fn simd_eq<Rhs>(self, other: Rhs) -> <u32x8 as CmpEq<Rhs>>::Output
pub fn simd_eq<Rhs>(self, other: Rhs) -> <u32x8 as CmpEq<Rhs>>::Output
Test if each element is equal to the corresponding element in other.
Sourcepub fn simd_ne<Rhs>(self, other: Rhs) -> <u32x8 as CmpNe<Rhs>>::Output
pub fn simd_ne<Rhs>(self, other: Rhs) -> <u32x8 as CmpNe<Rhs>>::Output
Test if each element is not equal to the corresponding element in
other.
Sourcepub fn simd_lt<Rhs>(self, other: Rhs) -> <u32x8 as CmpLt<Rhs>>::Output
pub fn simd_lt<Rhs>(self, other: Rhs) -> <u32x8 as CmpLt<Rhs>>::Output
Test if each element is less than the corresponding element in other.
Sourcepub fn simd_gt<Rhs>(self, other: Rhs) -> <u32x8 as CmpGt<Rhs>>::Output
pub fn simd_gt<Rhs>(self, other: Rhs) -> <u32x8 as CmpGt<Rhs>>::Output
Test if each element is greater than the corresponding element in
other.
Sourcepub fn simd_le<Rhs>(self, other: Rhs) -> <u32x8 as CmpLe<Rhs>>::Output
pub fn simd_le<Rhs>(self, other: Rhs) -> <u32x8 as CmpLe<Rhs>>::Output
Test if each element is less than or equal to the corresponding element
in other.
Sourcepub fn simd_ge<Rhs>(self, other: Rhs) -> <u32x8 as CmpGe<Rhs>>::Output
pub fn simd_ge<Rhs>(self, other: Rhs) -> <u32x8 as CmpGe<Rhs>>::Output
Test if each element is greater than or equal to the corresponding
element in other.
Sourcepub fn mul_keep_high(self, rhs: u32x8) -> u32x8
pub fn mul_keep_high(self, rhs: u32x8) -> u32x8
Multiplies 32x32 bit to 64 bit and then only keeps the high 32 bits of the
result. Useful for implementing divide constant value (see t_usefulness
example)
pub fn blend(self, t: u32x8, f: u32x8) -> u32x8
pub fn reduce_add(self) -> u32
pub fn reduce_max(self) -> u32
pub fn reduce_min(self) -> u32
pub fn max(self, rhs: u32x8) -> u32x8
pub fn min(self, rhs: u32x8) -> u32x8
Sourcepub fn clamp(self, min: u32x8, max: u32x8) -> u32x8
pub fn clamp(self, min: u32x8, max: u32x8) -> u32x8
Restrict each element to a certain interval.
If min > max, the result is unspeficied. Consider manually checking
for that case.
pub fn saturating_add(self, rhs: u32x8) -> u32x8
pub fn saturating_sub(self, rhs: u32x8) -> u32x8
Sourcepub fn saturating_mul(self, rhs: u32x8) -> u32x8
pub fn saturating_mul(self, rhs: u32x8) -> u32x8
Lanewise saturating multiply.
Sourcepub fn saturating_div(self, rhs: u32x8) -> u32x8
pub fn saturating_div(self, rhs: u32x8) -> u32x8
Lanewise saturating divide.
Note that because division has no hardware support, this operation is very slow and should be avoided if possible.
pub fn to_bitmask(self) -> u32
pub fn any(self) -> bool
pub fn all(self) -> bool
pub fn none(self) -> bool
Sourcepub fn transpose(data: [u32x8; 8]) -> [u32x8; 8]
pub fn transpose(data: [u32x8; 8]) -> [u32x8; 8]
Transpose matrix of 8x8 u32 matrix. Currently only accelerated on AVX2.
pub fn to_array(self) -> [u32; 8]
pub fn as_array(&self) -> &[u32; 8]
pub fn as_mut_array(&mut self) -> &mut [u32; 8]